# -*- coding: utf-8 -*-
# Copyright (C) 2022 mhertz <yourname@example.com>
#
# Basic plugin template created by the Deluge Team.
#
# This file is part of statesave and is licensed under GNU GPL 3.0, or later,
# with the additional special exception to link portions of this program with
# the OpenSSL library. See LICENSE for more details.
from __future__ import unicode_literals

import logging

import deluge.configmanager
from deluge.core.rpcserver import export
from deluge.plugins.pluginbase import CorePluginBase
import deluge.component as component
from twisted.internet import reactor

log = logging.getLogger(__name__)

DEFAULT_PREFS = {
    'interval': 20
}


class Core(CorePluginBase):
    def enable(self):
        self.config = deluge.configmanager.ConfigManager(
            'statesave.conf', DEFAULT_PREFS)
        self.config.save()
        component.get("EventManager").register_event_handler("SessionStartedEvent", self.z)

    def z(self):
        def f():
            a = self.config['interval'] * 60
            b = a - 10
            tmc = component.get("TorrentManager")
            tmc.save_state_timer.stop()
            tmc.save_resume_data_timer.stop()
            tmc.save_state_timer.start(a, False)
            tmc.save_resume_data_timer.start(b, False)
        reactor.callLater(1,f)

    def disable(self):
        component.get("EventManager").deregister_event_handler("SessionStartedEvent", self.z)

    def update(self):
        pass

    @export
    def set_config(self, config):
        """Sets the config dictionary"""
        for key in config:
            self.config[key] = config[key]
        self.config.save()
        self.z()

    @export
    def get_config(self):
        """Returns the config dictionary"""
        return self.config.config
