/**
 * Script: statesave.js
 *     The client-side javascript code for the statesave plugin.
 *
 * Copyright:
 *     (C) mhertz 2022 <yourname@example.com>
 *
 *     This file is part of statesave and is licensed under GNU GPL 3.0, or
 *     later, with the additional special exception to link portions of this
 *     program with the OpenSSL library. See LICENSE for more details.
 */

statesavePanel = Ext.extend(Ext.form.FormPanel, {
    constructor: function(config) {
        config = Ext.apply({
            border: false,
            title: _("statesave"),
            autoHeight: true,
        }, config);
        statesavePanel.superclass.constructor.call(this, config);
    },
    initComponent: function() {
        statesavePanel.superclass.initComponent.call(this);
        this.opts = new Deluge.OptionsManager();

        var fieldset = this.add({
            xtype: 'fieldset',
            title: _('statesave settings'),
            autoHeight: true,
            autoWidth: true,
            defaultType: 'textfield'
        });
        this.opts.bind('interval', fieldset.add({
			fieldLabel: _('Interval (min)'),
            anchor:'100%',
            name: 'interval',
            autoWidth: true,
            value: ''
        }));

        deluge.preferences.on('show', this.onPreferencesShow, this);
    },

    onPreferencesShow: function () {
        deluge.client.statesave.get_config({
            success: function (config) {
            if (!Ext.isEmpty(config['interval'])) {
                config['interval'] = config['interval'];
            }
           
            //Ext.getCmp("mycheck").checked;
            this.opts.set(config);
            },
            scope: this,
        });
    },
    onApply: function(e) {
        var changed = this.opts.getDirty();
        if (!Ext.isObjectEmpty(changed)) {
            if (!Ext.isEmpty(changed['interval'])) {
            changed['interval'] = changed['interval'];
            }
           
            deluge.client.statesave.set_config(changed, {
                success: this.onSetConfig,
                scope: this,
            });
        }
    },
    onSetConfig: function() {
        this.opts.commit();
    },
});


statesavePlugin = Ext.extend(Deluge.Plugin, {
    name: "statesave",

    onDisable: function() {
        deluge.preferences.removePage(this.prefsPage);
    },

    onEnable: function() {
        this.prefsPage = new statesavePanel();
        this.prefsPage = deluge.preferences.addPage(this.prefsPage);
    }
});

Deluge.registerPlugin('statesave', statesavePlugin);

